@@ -3,18 +3,18 @@ from fastapi import Depends
 from fief.db import AsyncSession
 from fief.db.main import get_main_async_session
 from fief.managers import (
-    AccountManager,
-    AccountUserManager,
     AdminAPIKeyManager,
     AdminSessionTokenManager,
+    WorkspaceManager,
+    WorkspaceUserManager,
     get_manager,
 )
 
 
-async def get_account_manager(
+async def get_workspace_manager(
     session: AsyncSession = Depends(get_main_async_session),
-) -> AccountManager:
-    return get_manager(AccountManager, session)
+) -> WorkspaceManager:
+    return get_manager(WorkspaceManager, session)
 
 
 async def get_admin_session_token_manager(
@@ -29,7 +29,7 @@ async def get_admin_api_key_manager(
     return get_manager(AdminAPIKeyManager, session)
 
 
-async def get_account_user_manager(
+async def get_workspace_user_manager(
     session: AsyncSession = Depends(get_main_async_session),
-) -> AccountUserManager:
-    return get_manager(AccountUserManager, session)
+) -> WorkspaceUserManager:
+    return get_manager(WorkspaceUserManager, session)
